============
Installation
============

At the command line::

    $ easy_install django-babel-underscore

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv django-babel-underscore
    $ pip install django-babel-underscore